@@ -6,9 +6,9 @@ function(obj)
 {
   fit.val <- obj$m$fitted()
   v <- attr(fit.val, "gradient")
-  if(is.null(v)) stop("gradient attribute missing")
+  if(is.null(v)) stop("\"gradient\" attribute missing")
   a <- attr(fit.val, "hessian")
-  if(is.null(a)) stop("hessian attribute missing")
+  if(is.null(a)) stop("\"hessian\" attribute missing")
   p <- ncol(v)
   n <- nrow(v)
   s <- sqrt(deviance(obj)/(n - p))
